summaryrefslogtreecommitdiffstats
path: root/Lib/site.py
diff options
context:
space:
mode:
authorRussell Keith-Magee <russell@keith-magee.com>2024-03-28 07:59:33 (GMT)
committerGitHub <noreply@github.com>2024-03-28 07:59:33 (GMT)
commitf006338017cfbf846e8f7391b9ee5f69df8dc620 (patch)
tree6db12f901d882f53401dc2d3fafbe101c2b8fdbc /Lib/site.py
parentb44898299a2ed97045c270f6474785da2ff07ced (diff)
downloadcpython-f006338017cfbf846e8f7391b9ee5f69df8dc620.zip
cpython-f006338017cfbf846e8f7391b9ee5f69df8dc620.tar.gz
cpython-f006338017cfbf846e8f7391b9ee5f69df8dc620.tar.bz2
gh-114099: Additions to standard library to support iOS (GH-117052)
Co-authored-by: Hugo van Kemenade <1324225+hugovk@users.noreply.github.com> Co-authored-by: Malcolm Smith <smith@chaquo.com> Co-authored-by: Ned Deily <nad@python.org>
Diffstat (limited to 'Lib/site.py')
-rw-r--r--Lib/site.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/site.py b/Lib/site.py
index 2aee63e..162bbec 100644
--- a/Lib/site.py
+++ b/Lib/site.py
@@ -280,8 +280,8 @@ def _getuserbase():
if env_base:
return env_base
- # Emscripten, VxWorks, and WASI have no home directories
- if sys.platform in {"emscripten", "vxworks", "wasi"}:
+ # Emscripten, iOS, tvOS, VxWorks, WASI, and watchOS have no home directories
+ if sys.platform in {"emscripten", "ios", "tvos", "vxworks", "wasi", "watchos"}:
return None
def joinuser(*args):